\name{analyzeIBDs}
\alias{analyzeIBDs}
\title{analyzeIBDs: A loop over all extracted haplotype cluters or IBD tracts for descriptive statistics}
\description{

  \code{analyzeIBDs}: \R implementation of \code{analyzeIBDs}.

  The functions provides a loop over all detected
  haplotype clusters or IBD tracts
  in order to compute descriptive statistics.

}
\usage{

analyzeIBDs(fileName="ALL.chr1.phase1_release_v2.20101123.snps_indels_svs",runIndex="",annotPostfix="_annot.txt",startRun=1,endRun=640,shift=5000,segmentSize=10000)


}
\arguments{
  \item{fileName}{file name prefix without type of the result of \code{hapFabia}; Attention no type!}
  \item{runIndex}{a string that marks this run if splitting the analysis.}
  \item{annotPostfix}{postfix string for the annotation file.}
 \item{startRun}{first segment.}
 \item{endRun}{last segment.}
 \item{shift}{distance between start of adjacent segments.}
 \item{segmentSize}{number of SNVs or SNPs in a segment.}

}
\details{

  The functions provides a loop over all detected
  haplotype clusters or IBD tracts
  in order to compute descriptive statistics. The loop goes over the segments
  that are analyzed by  \code{iterateSegments}.
  Duplicates are ignored and must be identified in a preceding step via \code{identifyDuplicates}.
  Other statistics and annotations are possible if the code is changed accordingly.

  Implementation in \R.

}
\value{
list containing:
 \item{startRun}{first segment.}
 \item{endRun}{last segment.}
  \item{noIBD}{number of haplotype clusters or IBD tracts.}
  \item{avibdPos}{vector of physical locations of haplotype clusters or IBD tracts.}
  \item{avibdLength}{vector of lengths of haplotype clusters or IBD tracts.}
  \item{avnoSamp}{vector of number of individuals that possess the haplotype or IBD tract.}
  \item{avnoSnps}{vector of number of tagSNVs that possess the haplotype or IBD tract.}
  \item{avnoFreq}{vector of minor allele frequencies of tagSNVs.}
  \item{avnoGroupFreq}{vector of minor allele frequencies within the considered set of tagSNVs.}
  \item{avnosnpChange}{vector of switching indicators where for each tagSNV 1' and 0's
      indicate whether minor and major allele are switched.}
  \item{avnosnpsPerSample}{vector of number of tagSNVs that are in a haplotype occurrence.}
  \item{avnosamplePerSnp}{vector of number of individuals that possess a haplotype
     tagged by a specific tagSNV.}
  \item{avibdPosS}{summary statistics of physical locations of haplotype clusters or IBD tracts.}
  \item{avibdLengthS}{summary statistics of lengths of haplotype clusters or IBD tracts.}
  \item{avnoSampS}{summary statistics of number of individuals that possess the haplotype or IBD tract.}
  \item{avnoSnpsS}{summary statistics of number of tagSNVs that possess the haplotype or IBD tract.}
  \item{avnoFreqS}{summary statistics of minor allele frequencies of tagSNVs.}
  \item{avnoGroupFreqs}{summary statistics of minor allele frequencies within the considered set of tagSNVs.}
  \item{avnosnpChangeS}{summary statistics of switching indicators where for each tagSNV 1' and 0's
      indicate whether minor and major allele are switched.}
  \item{avnosnpsPerSampleS}{summary statistics of number of tagSNVs that are in a haplotype occurrence.}
  \item{avnosamplePerSnpS}{summary statistics of number of individuals that possess a haplotype
     tagged by a specific tagSNV.}

    }
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{makePipelineFile}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{models,multivariate,cluster}
\concept{genetics,haplotype,identity by descent,bicluster,next generation sequencing,genotype,single nucleotide polymorphism,single nucleotide variation,rare variants,rare SNPs, rare SNVs,rare haplotype clusters,short haplotype clusters}

