\name{extractIBD}
\alias{extractIBD}
\title{extractIBD: Find accumulations of values via histogram counts}
\description{

  \code{extractIBD}: \R implementation of \code{extractIBD}.

  Extracts histogram bins which counts are larger than a threshold.
  Only loading values L larger than a given quantile are considered.
}
\usage{

extractIBD(rrnn,p=0.9,inte=500,thres=11,off=0)


}
\arguments{
  \item{rrnn}{values for constructing the histogram.}
 \item{p}{quantile above which the values of \code{rrnn} are included into the histogram.}
  \item{inte}{size of the histogram bins.}
  \item{thres}{threshold for histogram counts: bin with counts larger equal the threshold are selected.}
  \item{off}{offset of the histogram bin positions.}
}
\details{

  Extracts histogram bins which counts are larger than a threshold.
  The threshold is supplied and can be computed according to some assumptions
  on expected bin counts.
  Only loading values L larger than a given quantile are considered.



  Implementation in \R.

}
\value{
list with
  \item{m}{vector of locations of the selected bin (middle of bins).}
  \item{l}{vector of lengths of the bins.}
  \item{pos}{list where each element is a vector of locations of values that contributed to the counts (SNV positions).}
  \item{len}{vector of counts or equivalently vector of the number of SNVs.}

    }
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\examples{

data(res)
ib <- extractIBD(res@L[,1],p=0.9,inte=50,thres=6,off=0)
print(ib$len)

}

\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{models,multivariate,cluster}
\concept{genetics,haplotype,identity by descent,bicluster,next generation sequencing,genotype,single nucleotide polymorphism,single nucleotide variation,rare variants,rare SNPs, rare SNVs,rare haplotype clusters,short haplotype clusters}
