\name{hapFabia}
\alias{hapFabia}
\title{hapFabia: Haplotype cluster extraction by FABIA}
\description{

  \code{hapFabia}: \R implementation of the \emph{hapFabia} method.

  \code{hapFabia} extracts \bold{rare and short haplotype clusters} (or regions of
  identity by descent) from phased or unphased genotypes.
  It is designed for rare variants in very large sequencing data.
  The method is based on FABIA biclustering and utilizes the package
  \pkg{fabia}.

}
\usage{

hapFabia(fileName="ALL.chr1.phase1_release_v2.20101123.snps_indels_svs",prefixPath="",sparseMatrixPostfix="_mat",annotPostfix="_annot.txt",samplesPostfix="_samples.txt",labelsA=NULL,pRange="",samples=0,lowerBP=0,upperBP=0.05,p=10,iter=40,quant=0.01,eps=1e-5,alpha=0.03,cyc=50,non_negative=1,write_file=0,norm=0,lap=100.0,IBDlength=50,Lt = 0.1,Zt = 0.2,thresCount=1e-5,minSNPsFactor=3/4,pMAF=0.035,haplotypes=TRUE)
}


\arguments{

 \item{fileName}{file name of the genotype matrix in sparse format.}
 \item{prefixPath}{path to the genotype file.}
 \item{sparseMatrixPostfix}{postfix string for the sparse matrix.}
 \item{annotPostfix}{postfix string for the annotation file.}
 \item{samplesPostfix}{postfix string for the file containing sample names.}
 \item{labelsA}{sample names as matrix samples x 4.}
 \item{pRange}{indicates which segment is processed.}
 \item{samples}{vector of samples which should be included into the analysis; default = 0 (all samples).}
 \item{lowerBP}{lower bound on minor allele frequencies (MAF); however at least two occurrences are required to remove private SNPs.}
 \item{upperBP}{upper bound  on minor allele frequencies (MAF) to extract rare variants.}
 \item{p}{number of biclusters per iteration.}
 \item{iter}{number of iterations.}
 \item{quant}{percentage of loadings L to remove in each iteration.}
 \item{eps}{lower bound for variational parameter lapla; default 1e-5.}
 \item{alpha}{sparseness of the loadings; default = 0.03.}
 \item{cyc}{number of cycles per iterations; default 50.}
 \item{non_negative}{non-negative factors and loadings if non_negative = 1; default = 1 (yes).}
 \item{write_file}{results are written to files (L in sparse format), default = 0 (not written).}
 \item{norm}{data normalization; default 1 (no normalization).}
 \item{lap}{minimal value of the variational parameter; default 100.0.}
 \item{IBDlength}{typical IBD or haplotype cluster length in kbp.}
 \item{Lt}{percentage of largest L values to consider for IBD/haplotype cluster extraction.}
 \item{Zt}{percentage of largest Z values to consider for IBD/haplotype cluster extraction.}
 \item{thresCount}{p-value of random histogram hit; default 1e-5.}
 \item{minSNPsFactor}{percentage of IBD/haplotype cluster overlap; default 3/4.}
 \item{pMAF}{averaged and corrected (for non-uniform distributions) minor allele frequency.}
\item{haplotypes}{haplotypes = TRUE then phased genotypes meaning two chromosomes per individual otherwise unphased genotypes.}
}
\details{

 Uses genotype matrix in sparse matrix format and extracts haplotype clusters by
 biclustering.
 First Fabia biclustering and then extract local accumulations of loadings.
 Haplotype clusters are disentangled and pruned off spurious correlated SNVs.
 Similar and broken up haplotype clusters are finally merged.


 The function computes the probability of seeing  \eqn{k}{k} or more
 correlated SNVs in a bin. The minimal \eqn{k}{k} which pushes the
 probability below the threshold \code{thresCount} is used to find
 accumulation of correlated SNVs that are assumed to belong to a
 haplotype cluster.

 Let \eqn{p}{p} be the probability of a random
 minor allele match between \eqn{t}{t} individuals.
The probability of observing \eqn{k}{k} or more matches for
 \eqn{n}{n} SNVs in
 a bin is given by one minus the binomial distribution
 \eqn{F(k;n,p)}{F(k;n,p)}:

 \deqn{1 \ - \ F(k-1;n,p) \ = \ \Pr(K \geq k) \ = \
   \sum_{i=k}^\infty \ {n\choose i} \ p^i \ (1-p)^{n-i}}{1 - F(k-1;n,p)
   =  Pr(K >= k) = SUM(i = k to infinity; (n over i)  power(p,i) power(1-p,n-i))}
If \eqn{q}{q} is the minor allele frequency (MAF) for one SNV,
the probability \eqn{p}{p} of observing the minor allele of this SNV in
all \eqn{t}{t} individuals is \eqn{p=q^t}{p=power(q,t)}.
The value \eqn{q}{q} is given by the parameter \code{pMAF}.

 Implementation in \R.

}
\value{
List containing
 \item{mergedIBD}{the extracted haplotype clusters / IBD runs.}
 \item{res}{the result of FABIA.}
 \item{sPF}{samples per loading of this FABIA result.}
 \item{annot}{annotation for the genotype data.}
 \item{resIBD1}{result of haplotype cluster extraction from the first histogram.}
 \item{resIBD2}{result of haplotype cluster extraction from the second histogram.}
 \item{mergedIBD1}{merged first extraction.}
 \item{mergedIBD2}{merged second extraction.}

 }
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{makePipelineFile}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\examples{

library(fabia)
data(simu)
namesL <- simu[[1]]
haploN <- simu[[2]]
snps <- simu[[3]]
annot <- simu[[4]]
alleleIimp <- simu[[5]]
write.table(namesL,file="dataSim1fabia_samples.txt",quote = FALSE,row.names = FALSE,col.names = FALSE)
write(as.integer(haploN),file="dataSim1fabia_annot.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_annot.txt",append=TRUE,ncolumns=100)
write.table(annot,file="dataSim1fabia_annot.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
write(as.integer(haploN),file="dataSim1fabia_mat.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_mat.txt",append=TRUE,ncolumns=100)

for (i in 1:haploN) {

  a1 <- which(alleleIimp[i,]>0.01)

  al <- length(a1)
  b1 <- alleleIimp[i,a1]

  a1 <- a1 - 1
  dim(a1) <- c(1,al)
  b1 <- format(as.double(b1),nsmall=1)
  dim(b1) <- c(1,al)

  write.table(al,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(a1,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(b1,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)

}


hapRes <- hapFabia(fileName="dataSim1fabia",prefixPath="",upperBP=0.15,p=10,iter=1,IBDlength=10,pMAF=0.1)


unlink("dataSim1fabia_mat.txt")
unlink("dataSim1fabia_annot.txt")
unlink("dataSim1fabia_samples.txt")
unlink("dataSim1fabia_resIBD.Rda")
unlink("dataSim1fabia_mat_res_L.txt")
unlink("dataSim1fabia_mat_res_lapla.txt")
unlink("dataSim1fabia_mat_res_Psi.txt")
unlink("dataSim1fabia_mat_res_Z.txt")
unlink("dataSim1fabia_mat_res_Z_full.txt")

}

\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{models,multivariate,cluster}
\concept{genetics,haplotype,identity by descent,bicluster,next
  generation sequencing,genotype,single nucleotide polymorphism,single
  nucleotide variation,rare variants,rare SNPs, rare SNVs,rare
  haplotype clusters,short haplotype clusters, IBD}
