\name{mergeIBDres}
\alias{mergeIBDres}
\title{mergeIBDres: Merging and combining haplotype clusters or IBD tracts}
\description{

  \code{mergeIBDres}: \R implementation of \code{mergeIBDres}.

   Merges and combines the haplotype clusters or IBD tracts of one or two list(s) after
   comparing them by hierarchical clustering. Haplotype Clusters may be split up by bins or
   may be redundant. Called by \code{hapFabia}.

}
\usage{

mergeIBDres(resIBD1,resIBD2=NULL,comp,cut=0.8)


}
\arguments{
  \item{resIBD1}{list of haplotype clusters or IBD tracts.}
  \item{resIBD2}{optional: second list of haplotype clusters or IBD tracts.}
 \item{comp}{object of class hclust; tree as produced by hclust.}
 \item{cut}{numeric scalar or vector with heights where the tree should be cut.}

}
\details{

  Uses result \code{comp} of hclust and cuts the tree at \code{cut}.
  Haplotype Clusters that are clustered together are merged by an union of individuals
  and SNVs.

  Implementation in \R.

}
\value{
  \item{resIBDmerge}{list of merged haplotype clusters or IBD tracts.}

    }
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\examples{


data(hapRes)
resIBD1 <- hapRes$resIBD1
resIBD2 <- hapRes$resIBD2
comp <- compareIBDres(resIBD1,resIBD2,simv="minD")
if (!is.null(comp)) {
  mergedIBD12 <- mergeIBDres(resIBD1=resIBD2,resIBD2=resIBD2,comp=comp,cut=0.8)
} 
print(mergedIBD12[[1]]$ibdLength)
print(mergedIBD12[[1]]$ibdPos)

}

\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{models,multivariate,cluster}
\concept{genetics,haplotype,identity by descent,bicluster,next generation sequencing,genotype,single nucleotide polymorphism,single nucleotide variation,rare variants,rare SNPs, rare SNVs,rare haplotype clusters,short haplotype clusters}
