\name{plotOneIBD}
\alias{plotOneIBD}
\title{plotOneIBD: Plots a single haplotype cluster or IBD tract}
\description{

  \code{plotOneIBD}: \R implementation of \code{plotOneIBD}.

  Plots a single haplotype cluster or IBD tract showing reference alleles,
  minor alleles that are not tagSNVs,
  and minor alleles that are tagSNVs.

}
\usage{

plotOneIBD(IBD,filename,ibdC=1)


}
\arguments{
  \item{IBD}{list of haplotype clusters or IBD tracts.}
  \item{filename}{file name to call \code{readSamplesSpfabia} from the package \pkg{fabia}
  to read samples that should be plotted.}
\item{ibdC}{number of haplotype cluster or IBD tract that is plotted.
  ATTENTION: without type ".txt"!}

}
\details{

  Plots a single haplotype cluster or IBD tract showing reference alleles,
  minor alleles that are not tagSNVs,
  and minor alleles that are tagSNVs.
  Only the model from \pkg{fabia} is shown.


  Implementation in \R.

}
\seealso{
\code{\link{hapFabia}},
\code{\link{vcftoFABIA}},
\code{\link{split_sparse_matrix}},
\code{\link{iterateSegments}},
\code{\link{getIBDs}},
\code{\link{extractIBD}},
\code{\link{compareIBDres}},
\code{\link{mergeIBDres}},
\code{\link{identifyDuplicates}},
\code{\link{ibd2excel}},
\code{\link{plotRangeL}},
\code{\link{plotOneIBD}},
\code{\link{plotIBDs}},
\code{\link{snpPlot}},
\code{\link{analyzeIBDs}},
\code{\link{simulateHaplotypes}},
\code{\link{simulateForFabia}},
\code{\link{sim}},
\code{\link{topLZ}},
\code{\link{histL}},
\code{\link{plotL}},
\code{\link{hapRes}},
\code{\link{res}},
\code{\link{simu}},
\code{\link{mergedIBD}}
}
\author{Sepp Hochreiter}
\examples{

library(fabia)
data(hapRes)
data(simu)
namesL <- simu[[1]]
haploN <- simu[[2]]
snps <- simu[[3]]
annot <- simu[[4]]
alleleIimp <- simu[[5]]
write.table(namesL,file="dataSim1fabia_samples.txt",quote = FALSE,row.names = FALSE,col.names = FALSE)
write(as.integer(haploN),file="dataSim1fabia_annot.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_annot.txt",append=TRUE,ncolumns=100)
write.table(annot,file="dataSim1fabia_annot.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
write(as.integer(haploN),file="dataSim1fabia_mat.txt",ncolumns=100)
write(as.integer(snps),file="dataSim1fabia_mat.txt",append=TRUE,ncolumns=100)

for (i in 1:haploN) {

  a1 <- which(alleleIimp[i,]>0.01)

  al <- length(a1)
  b1 <- alleleIimp[i,a1]

  a1 <- a1 - 1
  dim(a1) <- c(1,al)
  b1 <- format(as.double(b1),nsmall=1)
  dim(b1) <- c(1,al)

  write.table(al,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(a1,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)
  write.table(b1,file="dataSim1fabia_mat.txt", sep = " ", quote = FALSE,row.names = FALSE,col.names = FALSE,append=TRUE)

}

mergedIBD <- hapRes$mergedIBD
devAskNewPage(ask = FALSE)
plotOneIBD(mergedIBD,filename="dataSim1fabia_mat")

unlink("dataSim1fabia_mat.txt")
unlink("dataSim1fabia_annot.txt")
unlink("dataSim1fabia_samples.txt")


}

\references{

S. Hochreiter et al.,
\sQuote{FABIA: Factor Analysis for Bicluster Acquisition},
Bioinformatics 26(12):1520-1527, 2010.

}
\keyword{hplot}
\concept{genetics,haplotype,identity by descent,bicluster,next generation sequencing,genotype,single nucleotide polymorphism,single nucleotide variation,rare variants,rare SNPs, rare SNVs,rare haplotype clusters,short haplotype clusters}
